;; EMERGENT GARBAGE CANS




;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; Variables Declaration ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
extensions [array]

globals [
          ;; Stop condition. Necessary in order to stop the simulation from inside procedures.
          stop?

          ;; Kinds of decision-making and kinds of flights.
          cum-oversights ;; cumulative number of decisions by oversight
          cum-resolutions ;; cumulative number of decisions by resolution
          cum-postponements-outside-organization ;; cumulative number of flights by postponement taking place with opportunities that have been found outside one's own organization
          cum-postponements-inside-organization ;; cumulative number of flights by postponement taking place with opportunities that have been found inside one's own organizations
          cum-buck-passings-outside-organization ;; cumulative number of flights by buck-passing taking place with independent participants
          cum-buck-passings-inside-organization ;; cumulative number of flights by buck-passing taking place with organization members

          ;; Oversights and resolutions for organization founders, organization associates and independent participants.
          cum-oversights-founders ;; cumulative number of decisions by oversight made by at least one organization founder
          cum-resolutions-founders ;; cumulative number of decisions by resolution made by at least one organization founder
          ove/res-founders ;; the ratio of the above magnitudes
          cum-oversights-associates ;; cumulative number of decisions by oversight participated by no organization founder and made by at least one organization associate
          cum-resolutions-associates ;; cumulative number of decisions by resolution participated by no organization founder and made by at least one organization associate
          ove/res-associates ;; the ratio of the above magnitudes
          cum-oversights-independents ;; cumulative number of decisions by oversight participated by no organization founder or associate and made by at least one independent participant
          cum-resolutions-independents ;; cumulative number of decisions by resolution participated by no organization founder or associate and made by at least one independent participant
          ove/res-independents ;; the ratio of the above magnitudes

          ;; Percentages of organization founders, organization associates, and independent participants making decisions.
          num-founders-oversights
          num-founders-resolutions
          num-associates-oversights
          num-associates-resolutions
          num-independents-oversights
          num-independents-resolutions
          percent-founders-deciding
          cum-percent-founders-deciding
          ave-percent-founders-deciding
          percent-associates-deciding
          cum-percent-associates-deciding
          ave-percent-associates-deciding
          percent-independents-deciding
          cum-percent-independents-deciding
          ave-percent-independents-deciding

          ;; The number of independent participants, organization members and the number of organizations, with time:
          ;; random: independent participants with random heading
          ;; headed: independent participants with heading 0
          ;; O: organizations created with a decision by oversight
          ;; R: organizations created with a decision by resolution
          random-independents-list
          headed-independents-list
          O-organizations-members-list
          R-organizations-members-list
          O-organizations-list
          R-organizations-list

          ;; Lists of organizations by size.
          O-organization-size-list
          R-organization-size-list
          ;; The lists of organizations by size over the whole simulation are interesting.
          ;; At simulation end, they are transformed into distributions of organizations by size.
          cum-O-organization-size-list
          cum-R-organization-size-list

          ;; Lists of organization life lengths.
          O-mortality-list
          R-mortality-list
          ;; List of blocked decision processes life lengths.
          blocked-time-list
        ]

;; A variable common to all turtles.
turtles-own [blocked?]

;; Our four classes of turtles. Their order in this sequence reflects into the depth of their representation on the world.
breed [solutions solution]
breed [opportunities opportunity]
breed [participants participant]
breed [problems problem]

;; Their variables.
participants-own [;; This variable is used by all participants.
                 ability
                 ;; These variables are used by participants involved in buck-passing.
                 charged?
                 with-problem
                 ;; These variables are only used by participants who are also organization members.
                 organization
                 owns-solution
                 owns-efficiency
                 ;; These variables are only used by organization founders.
                 ;; The 'label' is here used to identify organizations that have been either created with a decision by oversight or a decision by resolution.
                 date-of-founding  ; at which step the organization was created
                 organization-size  ; the number of organization members, including its founder
                 endowment  ; an organization's endowment (to be used by organization founders only)
                ]
opportunities-own [;; The in-built variable 'hidden?' is used by opportunities that move within organizations. The ensuing variables are used by opportunities involved in postponements.
                   charged?
                   with-problem
                  ]
solutions-own [;; This variable is used by all solutions.
               efficiency
               ;; These variables are used by solutions owned by organization founders.
               owned?
               by-participant
              ]
problems-own [;; This variable is used by all problems.
              difficulty
              ;; These variables are used by problems involved in postponements.
              postponed?
              to-opportunity
              ;; These variables are used by problems involved in buck-passings.
              passed?
              to-participant
             ]
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;







;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;; What is done when the "Setup" button is pressed ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to setup
  clear-all
  set stop? false

  ;; Initializes the number of kinds of decision-making and flights.
  set cum-oversights 0
  set cum-resolutions 0
  set cum-postponements-outside-organization 0
  set cum-postponements-inside-organization 0
  set cum-buck-passings-outside-organization 0
  set cum-buck-passings-inside-organization 0

  ;; Initializes the kinds of decision-making by all involved participants, by status.
  set cum-oversights-founders 0
  set cum-resolutions-founders 0
  set ove/res-founders "N/A"
  set cum-oversights-associates 0
  set cum-resolutions-associates 0
  set ove/res-associates "N/A"
  set cum-oversights-independents 0
  set cum-resolutions-independents 0
  set ove/res-independents "N/A"

  ;; Initializes the number of founders, associates and independents making decisions at each step.
  ;; Initializes the cumulative percentages of organization founders, organization associates, and independent participants making decisions.
  set num-founders-oversights 0
  set num-founders-resolutions 0
  set num-associates-oversights 0
  set num-associates-resolutions 0
  set num-independents-oversights 0
  set num-independents-resolutions 0
  set cum-percent-founders-deciding 0
  set cum-percent-associates-deciding 0
  set cum-percent-independents-deciding 0

  ;; Initializes the counters of independent participants, organization members and organizations.
  set random-independents-list []
  set headed-independents-list []
  set O-organizations-members-list []
  set R-organizations-members-list []
  set O-organizations-list []
  set R-organizations-list []

  ;; Initializes the lists of the data on the distribution of organization size.
  set cum-O-organization-size-list []
  set cum-R-organization-size-list []

  ;; Initializes the lists of organization life lengths.
  set O-mortality-list []
  set R-mortality-list []
  ;; Initializes the list of blocked decision processes life lengths.
  set blocked-time-list []

  ;; creates the agents that are initially present in the organization. Heading should be different from zero.
  set-default-shape participants "participant"
  create-participants agents-per-breed  ;; creates the participants and initializes their variables
  [
    setxy random world-width random world-height
    set color yellow
    set heading (1 + random 359)
    set ability random-float (max-ability - min-ability) + min-ability
    set blocked? false
    set charged? false
    set with-problem nobody
    set organization -1
    set owns-solution nobody
    set owns-efficiency -1
    set label ""
    set date-of-founding -1
    set organization-size 0
    set endowment 0
  ]
  set-default-shape opportunities "opportunity"
  create-opportunities agents-per-breed  ;; creates the choice opportunities and initializes their variables
  [
    setxy random world-width random world-height
    set color orange
    set blocked? false
    set charged? false
    set with-problem nobody
  ]
  set-default-shape solutions "solution"
  create-solutions agents-per-breed  ;; creates the solutions and initializes their variables
  [
    setxy random world-width random world-height
    set color red
    set blocked? false
    set owned? false
    set by-participant nobody
    set efficiency random-float (max-efficiency - min-efficiency) + min-efficiency
  ]
  set-default-shape problems "problem"
  create-problems agents-per-breed  ;; creates the problems and initializes their variables
  [
    setxy random world-width random world-height
    set color violet
    set blocked? false
    set postponed? false
    set to-opportunity nobody
    set passed? false
    set to-participant nobody
    set difficulty random-float (max-difficulty - min-difficulty) + min-difficulty
  ]

  reset-ticks
end
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;












;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; What is done when the "Go Step" button is pressed and what is repeated at each step when the "Go Until" button is pressed
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to go

  ;; THE SIMULATION IS NOT ALLOWED TO BEGIN IF MINIMUM VALUES OF ABILITY, EFFICIENCY AND DIFFICULTY ARE GREATER THAN THE CORRESPONDING MAXIMUM VALUES.
  if (min-ability > max-ability) [
    print "MINIMUM ABILITY SHOULD NOT BE GREATER THAN MAXIMUM ABILITY"
    stop
  ]
  if (min-efficiency > max-efficiency) [
    print "MINIMUM EFFICIENCY SHOULD NOT BE GREATER THAN MAXIMUM EFFICIENCY"
    stop
  ]
  if (min-difficulty > max-difficulty) [
    print "MINIMUM DIFFICULTY SHOULD NOT BE GREATER THAN MAXIMUM DIFFICULTY"
    stop
  ]








;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; DECISION - MAKING

  ;; At the beginning of each step, decreases organizations' endowment of resources by an amount proportional to organization size.
  ask participants with [color = gray and owns-solution != nobody]
    [set endowment (endowment - decay * organization-size)]
  ;; Though decisions are made by participants, it is more convenient to let patches check the conditions for participants to operate.
  ask patches [
    ;; Resets to black the patches where a decision was made or a decision process was blocked.
    ;; Later on, the white colour is confirmed if the decision process is still blocked.
    if (pcolor = lime or pcolor = sky or pcolor = white)
      [set pcolor black]

    ;; EITHER A DECISION IS MADE, EVENTUALLY AFTER A FLIGHT, OR A DECISION PROCESS IS BLOCKED
    ;; Opportunities within organizations are hidden once a decision is made, because they would make long series of decisions by oversight otherwise.
    ;; If there is (1) at least one non-hidden opportunity, one independent participant and one solution, or
    ;;             (2) at least one non-hidden choice opportunity and one organization member who is not charged with a difficult problem, or
    ;;             (3) at least one opportunity, even a hidden one, and an organization member charged with a difficult problem, then something is done.
    if ((any? opportunities-here with [not hidden?] and any? participants-here with [color = yellow] and any? solutions-here) or
        (any? opportunities-here with [not hidden?] and any? participants-here with [color = gray and not charged?]) or
        (any? opportunities-here and any? participants-here with [color = gray and charged?])) [

      ;; EITHER A DECISION BY RESOLUTION IS MADE, OR THE DECISION PROCESS IS BLOCKED
      ;; If there are problems as well, either they are resolved if their ability is sufficient or all agents stay put until another opportunity or another participant passes by and takes a problem away.
      ifelse (any? problems-here) [
        ;; Available efficiency is the maximum one if only independent participants are there. If there is one organization member, the available efficiency is the one provided by the organization.
        let available-efficiency -1
        ifelse (any? participants-here with [color = gray])
          [set available-efficiency [owns-efficiency] of one-of (participants-here with [color = gray])]
          [set available-efficiency [efficiency] of max-one-of solutions-here [efficiency]]

        ;; A DECISION BY RESOLUTION IS MADE
        ;; If the ability of participants, multiplied by the available efficiency, is greater or equal than the sum of the difficulty of all problems on the same patch, then decisions are made by resolution.
        ifelse (sum [ability] of participants-here * available-efficiency >= (sum [difficulty] of problems-here)) [

          ;; Blocked decision processes are unleashed, charged opportunities and charged participants are freed, their problems are detached from them.
          ask participants-here [
            ;; Independent participants are set free to move.
            if (color = yellow and blocked?)
              [set blocked? false]
            ;; Charged participants are freed of problems.
            if (charged?) [
              set charged? false
              set with-problem nobody
            ]
          ]
          ask opportunities-here [
            ;; Blocked opportunities are set free to move.
            if (blocked?)
              [set blocked? false]
            ;; Charged opportunities are freed of problems.
            if (charged?) [
              set charged? false
              set with-problem nobody
            ]
          ]
          ask solutions-here with [not owned?]
            ;; Unless they are owned by an organization, blocked solutions are set free to move.
            [set blocked? false]
          ask problems-here [
            ;; Blocked problems are set free to move.
            if (blocked?)
              [set blocked? false]
            ;; Postponed problems are detached from their opportunity.
            if (postponed?) [
              set postponed? false
              set to-opportunity nobody
            ]
            ;; Passed problems are detached from their participant.
            if (passed?) [
              set passed? false
              set to-participant nobody
            ]
          ]

          ;; Counts the number of resolutions, the number of resolutions by status of participants, and the number of resolutions per participant distinguished by status.
          ;; The condition on organization size is there in order to exclude organizations composed by their founder only.
          ;; Therefore, cum-resolutions != cum-resolutions-founders + cum-resolutions-associates + cum-resolutions-independents.
          set cum-resolutions cum-resolutions + 1
          ifelse (any? participants-here with [color = gray and owns-solution != nobody and organization-size > 1]) [
            set cum-resolutions-founders cum-resolutions-founders + 1
          ][
            ifelse (any? participants-here with [color = gray and owns-solution = nobody]) [
              set cum-resolutions-associates cum-resolutions-associates + 1
            ][
              if (any? participants-here with [color = yellow])
                [set cum-resolutions-independents cum-resolutions-independents + 1]
            ]
          ]
          ;; Counts the number of participants involved in resolutions.
          set num-founders-resolutions count participants-here with [color = gray and owns-solution != nobody]
          set num-associates-resolutions num-associates-resolutions + count participants-here with [color = gray and owns-solution = nobody]
          set num-independents-resolutions count participants-here with [color = yellow]

          ;; A decision by resolution is marked by a green square.
          set pcolor lime

          ;; If an organization was involved, its founder updates the organization's endowment with the difficulty of the problems that have been solved.
          if (any? participants-here with [color = gray]) [
            let this-organization [organization] of one-of participants-here with [color = gray]
            let difficultyOfSolvedProblems sum [difficulty] of problems-here
            ask participants with [color = gray and owns-solution != nobody and organization = this-organization] [
              set endowment (endowment + difficultyOfSolvedProblems)
            ]
            ;; If decision-making occurred within an organization, the one opportunity that was involved is hidden.
            ;; (it actually selects one opportunity at random, but it makes no difference)
            ask one-of opportunities-here
              [set hidden? true]
          ]

          ;; If no organization member was involved, a new organization is founded.
          ;; The conditions to form a new organization. First of all, that organizations are allowed and that the participant making a decision here is not an organization member.
          if (organizations? and not any? participants-here with [color = gray]) [
            ;; Secondly, that either no organization exists at all, or that the independent participant available here has heading=0. Only if one of these conditions hold, a new organization can be created.
            if (not any? participants with [color = gray] or any? participants-here with [color = yellow and heading = 0]) [
              ;; If no organization exists, just select the most able independent participant on this patch to found a new organization.
              ;; If organizations exist, then select the most able independent participant on this patch with heading=0 to found a new organization.
              let founder nobody
              ifelse (not any? participants with [color = gray])
                [set founder max-one-of participants-here with [color = yellow] [ability]]
                [set founder max-one-of participants-here with [color = yellow and heading = 0] [ability]]
              let its-solution max-one-of solutions-here [efficiency]
              ask founder [
                set blocked? true
                set heading 0
                set color gray
                set organization who
                set organization-size 1
                set label "R"
                set date-of-founding ticks
                set owns-solution its-solution
                set owns-efficiency [efficiency] of its-solution
                set endowment ability
              ]
              ask its-solution [
                set blocked? true
                set owned? true
                set by-participant founder
              ]
            ]
          ]
        ]

        ;; THE DECISION PROCESS IS BLOCKED, FLIGHTS ARE ATTEMPTED AND EVENTUALLY SCHEDULED FOR THE NEXT STEP
        ;; If the ability of the participants is not sufficient to make a decision, the decision process is blocked.
        ;; Subsequently, flights are attempted. Eventually, couples problem-opportunity or problem-participant are paired and unblocked.
        ;; If an organization member is involved, it looks for an opportunity or a participant within the organization if freely moving ones are not available.
        [

          ;; Freely moving agents are blocked, charged opportunities and charged participants are freed and detached from them.
          ask participants-here [
            ;; Independent participants are blocked.
            if (color = yellow)
              [set blocked? true]
            ;; Charged participants are freed of problems.
            if (charged?) [
              set charged? false
              set with-problem nobody
            ]
          ]
          ask opportunities-here [
            ;; Opportunities are blocked.
            set blocked? true
            ;; Hidden opportunities are made visible. This is essential in order to decisions eventually to be made where the process is temporarily blocked.
            if (hidden?)
              [set hidden? false]
            ;; Charged opportunities are freed of problems.
            if (charged?) [
              set charged? false
              set with-problem nobody
            ]
          ]
          ask solutions-here with [owned? = false] [
            ;; Solutions are blocked.
            set blocked? true
          ]
          ask problems-here [
            ;; Problems are blocked.
              set blocked? true
            ;; Postponed problems are detached from their opportunity.
            if (postponed?) [
              set postponed? false
              set to-opportunity nobody
            ]
            ;; Passed problems are detached from their participant.
            if (passed?) [
              set passed? false
              set to-participant nobody
            ]
          ]

          ;; A blocked decision process is marked by a white square.
          ;; The patch's label records the time when the decision process got blocked.
          set pcolor white
          if (plabel = "")
            [set plabel ticks]

          ;; A FLIGHT BY POSTPONEMENT IS ATTEMPTED AND EVENTUALLY SCHEDULED
          ;; A FLIGHT BY BUCK-PASSING WILL ONLY BE ATTEMPTED IF NO FLIGHT BY POSTPONEMENT WAS POSSIBLE
          let flightByPostponement? false

          if (postpone?) [
            ;; First, the most difficult problem is selected for the flight.
            let which-problem-for-opportunity max-one-of problems-here [difficulty]
            ;; Secondly, an opportunity is sought and eventually selected for the flight.
            let which-opportunity nobody
            ;; If at least two opportunities are there, one of them is selected.
            if (count opportunities-here > 1) [
              set which-opportunity one-of opportunities-here
              set flightByPostponement? true
              set cum-postponements-outside-organization cum-postponements-outside-organization + 1
            ]
            ;; If only one opportunity is there but an organization member is involved, he looks for another opportunity within the organization.
            if (any? participants-here with [color = gray] and count opportunities-here = 1) [
              ask one-of participants-here with [color = gray] [
                let this-organization organization
                if (any? other participants with [organization = this-organization]) [
                  ask other participants with [organization = this-organization] [
                    ;; Hidden opportunities can be used by organizations in order to postpone a problem.
                    ;; Blocked opportunities, as well as opportunities charged with a problem, cannot.
                    if (any? opportunities-here with [not blocked? and not charged?]) [
                      set which-opportunity one-of opportunities-here with [not blocked? and not charged?]
                      set flightByPostponement? true
                      set cum-postponements-inside-organization cum-postponements-inside-organization + 1
                    ]
                  ]
                ]
              ]
            ]
            ;; A flight by postponement takes place by attaching the most difficult problem to the selected opportunity.
            ;; Subsequently, they will move away.
            if (flightByPostponement? = true) [
              ;; The selected opportunity is charged with the selected problem.
              ask which-opportunity [
                set blocked? false
                set charged? true
                set with-problem which-problem-for-opportunity
              ]
              ;; The selected problem is attached to the selected opportunity.
              ask which-problem-for-opportunity [
                set blocked? false
                set postponed? true
                set to-opportunity which-opportunity
              ]
            ]
          ] ; end of postponement

          ;; A FLIGHT BY BUCK-PASSING IS ATTEMPTED AND EVENTUALLY SCHEDULED
          ;; A FLIGHT BY BUCK-PASSING CAN ONLY BE ATTEMPTED IF NO FLIGHT BY POSTPONEMENT WAS POSSIBLE
          let flightByBuckPassing? false

          if (buck-pass? and flightByPostponement? = false)  [
            ;; First, the most difficult problem is selected for the flight.
            let which-problem-for-participant max-one-of problems-here [difficulty]
            ;; Secondly, a participant is sought and eventually selected for the flight.
            let which-participant nobody
            ;; If at least two participants are there and if at least one of then is an independent participant, he gets the buck.
            if (any? participants-here with [color = yellow] and count participants-here > 1) [
              set which-participant one-of participants-here with [color = yellow]
              set flightByBuckPassing? true
              set cum-buck-passings-outside-organization cum-buck-passings-outside-organization + 1
            ]
            ;; If no independent participant is there but an organization member is there, he looks for someone in the organization to pass the buck to.
            if (not any? participants-here with [color = yellow] and any? participants-here with [color = gray]) [
              ask one-of participants-here with [color = gray] [
                let this-organization organization
                ;; The victim must not be charged with a problem, already, but it can be someone who is stuck in a blocked decision process.
                if (count other participants with [organization = this-organization and not charged?] > 0) [
                  set which-participant one-of other participants with [organization = this-organization and not charged?]
                  set flightByBuckPassing? true
                  set cum-buck-passings-inside-organization cum-buck-passings-inside-organization + 1
                ]
              ]
            ]
            ;; A flight by buckpassing takes place by attaching the most difficult problem to the selected participant.
            ;; Subsequently, they will move away.
            if (flightByBuckPassing? = true) [
              ;; The selected participant is charged with the selected problem.
              ask which-participant [
                if (color = yellow)
                  [set blocked? false]
                set charged? true
                set with-problem which-problem-for-participant
              ]
              ;; The selected problem is attached to the selected participant.
              ask which-problem-for-participant [
                set blocked? false
                set passed? true
                set to-participant which-participant
              ]
            ]
          ] ; end of buck-passing
        ] ; end of the second half of 'ifelse (sum [ability] of participants-here * available-efficiency >= (sum [difficulty] of problems-here))'
      ]  ; end of the first half of 'ifelse (any? problems-here)'

      ;; IF NO PROBLEM IS THERE, DECISIONS ARE MADE BY OVERSIGHT
      ;; If there is at least one independent participant, he makes the decision. If there are many, they all make the decision.
      ;; If there no independent participant is there but one organization member is there, then one randomly selected member of that organization makes the decision.
      [
        ;; Counts the number of oversights, the number of oversights by status of participants, and the number of oversights per participant distinguished by status.
        set cum-oversights cum-oversights + 1

        ;; The deicion maker. Either an independent participant, or a randomly selected organization member.
        let the-decision-maker nobody

        ;; If the decision is made by an independent participant.
        ifelse (any? participants-here with [color = yellow]) [
          set the-decision-maker one-of participants-here with [color = yellow]
          set cum-oversights-independents cum-oversights-independents + 1
          set num-independents-oversights count participants-here with [color = yellow]
        ][
          ;; If no independent participant is there, but an organization member is there, one member of that organization member is selected.
          let this-organization [organization] of one-of participants-here with [color = gray]
          ;; Creates a list and sorts it inversely on organization size.
          ;; Since for organization associates organization-size=0, the founder comes first.
          ;; Thus, the founder first attempts to make a decision by oversight. Associates do it only if the founder could not, for instance because it's in a blocked decision process.
          let list-of-candidates sort-on [(- organization-size)] participants with [organization = this-organization]
          let found? false
          foreach list-of-candidates [ candidate ->
            ask candidate [
              if (not any? problems-here and found? = false) [
                set the-decision-maker candidate
                set found? true
              ]
            ]
          ]

          ;; One opportunity is moved to the randomly chosen organization member and a decision by oversight is made there.
          ;; This opportunity is hidden once the decision is made. This, in order to impair it from making many other decisions once it's in the organization.
          ask one-of opportunities-here [
            move-to the-decision-maker
            set hidden? true
          ]
          ifelse ([owns-solution] of the-decision-maker = nobody) [
            set num-associates-oversights num-associates-oversights + 1
            set cum-oversights-associates cum-oversights-associates + 1
          ][
            set num-founders-oversights num-founders-oversights + 1
            set cum-oversights-founders cum-oversights-founders + 1
          ]
        ]

        ;; A decision by oversight is marked by a sky-blue square.
        ask the-decision-maker [
          ask patch-here [set pcolor sky]
        ]

        ;; Here come a few things to do if this decision unleashed a blocked decision process.
        ;; Since no problems are there, participants and opportunities do not need to be freed of them.
        ask the-decision-maker [
          ;; Opportunities are set free to move.
          ask opportunities-here
            [set blocked? false]
          ;; Unless they are owned by an organization, the solutions involved in this decision are set free to move.
          ask solutions-here with [not owned?]
            [set blocked? false]
          ;; Independent participants are set free to move.
          if (color = yellow)
            [set blocked? false]
        ]

        ;; The conditions to form a new organization. First of all, that organizations are allowed and that no organization is already there.
        if (organizations? and not any? participants-here with [color = gray]) [
          ;; Secondly, that either no organization exists at all, or that the independent participant available here has heading=0. Only if one of these conditions hold, a new organization can be created.
          if (not any? participants with [color = gray] or any? participants-here with [color = yellow and heading = 0]) [
            ;; If no organization exists, just select the most able independent participant on this patch to found a new organization.
            ;; If organizations exist, then select the most able independent participant on this patch with heading=0 to found a new organization.
            let founder nobody
            ifelse (not any? participants with [color = gray])
              [set founder max-one-of participants-here with [color = yellow] [ability]]
              [set founder max-one-of participants-here with [color = yellow and heading = 0] [ability]]
            let its-solution max-one-of solutions-here [efficiency]
            ask founder [
              set blocked? true
              set heading 0
              set color gray
              set organization who
              set organization-size 1
              set label "O"
              set date-of-founding ticks
              set owns-solution its-solution
              set owns-efficiency [efficiency] of its-solution
              set endowment ability
            ]
            ask its-solution [
              set blocked? true
              set owned? true
              set by-participant founder
            ]
          ]
        ]
      ]
    ]
  ]











  ;;;;;;;;;;;;;;;;;;;;;;;;;; INDEPENDENT PARTICIPANTS AND OTHER AGENTS MOVE
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; ORGANIZATIONS GROW

  ;; Independent uncharged participants move randomly, but are attracted by organizations and eventually enter them.
  ask participants with [color = yellow and not blocked? and not charged?] [
    ;; If it meets an organization member.
    ifelse (any? participants-here with [color = gray]) [
      ;; This participant enters the organization.
      let organizationtojoin [organization] of one-of participants-here with [color = gray]
      set date-of-founding [date-of-founding] of one-of participants-here with [color = gray]
      set organization organizationtojoin
      set owns-solution nobody
      set owns-efficiency [owns-efficiency] of one-of participants with [who = organizationtojoin]
      set label [label] of one-of participants with [who = organizationtojoin]
      set heading 0
      set color gray
      ;; Finds a new place. It asks the founder to look for a slot in the surrounding space.
      let x-destination -1
      let y-destination -1
      ask one-of participants with [who = organizationtojoin and owns-solution != nobody] [
        let radius 1
        while [x-destination = -1 and y-destination = -1] [
          ask one-of patches in-radius radius [
            if (not any? participants-here with [color = gray]) [
              set x-destination pxcor
              set y-destination pycor
            ]
          ]
          ;; If there is no free square within the current circle, it increases its radius.
          if (count participants with [color = gray] in-radius radius >= count patches in-radius radius)
            [set radius radius + 1]
        ]
      ]
      ;; The newcomer moves to its new place and stays there.
      setxy x-destination y-destination
      set blocked? true
      ;; If the independent participant didn't meet any organization member, it continues its random walk.
    ] [
      move-to patch-at-heading-and-distance ((random 4) * 90) 1
    ]
  ]

  ;; Independent participants get ready to found a new organization once they met one.
  ask participants with [color = yellow] [
    if (any? (participants-on neighbors) with [color = gray])
      [set heading 0]
  ]

  ;; Unblocked uncharged opportunities move randomly.
  ask opportunities with [not (blocked? or charged?)] [
    move-to patch-at-heading-and-distance ((random 4) * 90) 1
    ;; If they are hidden, they are made visible if they exit the area where an organization is.
    if (hidden? and not any? participants-here with [color = gray])
      [set hidden? false]
  ]

  ;; Unowned solutions move randomly.
  ask solutions with [not (blocked? or owned?)] [
    move-to patch-at-heading-and-distance ((random 4) * 90) 1
  ]

  ;; Unpostponed and unpassed problems move randomly.
  ask problems with [not (blocked? or postponed? or passed?)] [
    move-to patch-at-heading-and-distance ((random 4) * 90) 1
  ]

  ;; Paired couples move together.
  ;; Patches where a decision process was blocked are set back to black.
  ask patches [
    ;; Problems follow opportunities. A paired couple is marked by a brown square.
    ask opportunities-here with [charged?] [
      set pcolor black
      ;; Charged opportunities are not hidden, even if they are within organizations.
      if (hidden?)
        [set hidden? false]
      move-to patch-at-heading-and-distance ((random 4) * 90) 1
      set pcolor brown
    ]
    ask problems-here with [postponed? and to-opportunity != nobody] [
      move-to to-opportunity
    ]
    ;; Problems follow participants. A paired couple is marked by a brown square.
    ask participants-here with [charged?] [
      if (color = yellow) [
        set pcolor black
        move-to patch-at-heading-and-distance ((random 4) * 90) 1
      ]
      set pcolor brown
    ]
    ask problems-here with [passed? and to-participant != nobody] [
      move-to to-participant
    ]
  ]












  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; IDLE ORGANIZATIONS ARE DISMANTLED

  ;; For simplicity of coding, when an organization is dismantled charged participants and opportunities that are eventually moving through its area are freed of their problems.
  ;; Correspondingly, postponed and passed problems are detached from opportunities and problems, respectively.
  if (organizations?) [
    ask participants with [color = gray and owns-solution != nobody] [
      ;; If an organization's endowment shrinks down to zero, this organization is dismantled.
      if (endowment <= 0) [
        ;; Stores data on the mean life of O-organizations and R-organizations.
        if (label = "O") [
          set O-mortality-list fput (ticks - date-of-founding) O-mortality-list
        ]
        if (label = "R") [
          set R-mortality-list fput (ticks - date-of-founding) R-mortality-list
        ]
        ;; Dismantles the organization.
        ;; First of all, the organizational solution is set free.
        ask solutions-here with [owned? and by-participant = myself] [
          set blocked? false
          set owned? false
          set by-participant nobody
        ]
        ;; The founder asks organization associates to turn the underlying patches' color black.
        ;; The founder ask organization associates to make underlying opportunities visible, mobile, and free of problems.
        ;; The founder ask organization associates to make underlying problems mobile and neither attached to opportunities, nor to participants.
        ;; The founder ask organization associates to free underlying independent participants charged with problems.
        ;; The founder ask organization associates to turn into independent participants who never met any organization.
        ;; Finally, the founder turs itself into an independent participant who never met any organization.
        ask other participants with [(color = gray) and organization = [organization] of myself] [
          ask patch-here [
            set pcolor black
          ]
          ask opportunities-here [
            set hidden? false
            set blocked? false
            set charged? false
            set with-problem nobody
          ]
          ask problems-here [
            set passed? false
            set to-participant nobody
            set postponed? false
            set to-opportunity nobody
            set blocked? false
          ]
          ask participants-here with [color = yellow] [
            set charged? false
            set with-problem nobody
          ]
          set heading (1 + random 359)
          set color yellow
          set label ""
          set organization -1
          set owns-efficiency -1
          set blocked? false
          set charged? false
          set with-problem nobody
        ]
        ;; Finally, the organization's founder frees itself.
        set owns-solution nobody
        set heading (1 + random 359)
        set color yellow
        set organization -1
        set organization-size 0
        set label ""
        set date-of-founding -1
        set endowment 0
        set owns-efficiency -1
        set blocked? false
      ]
    ]
  ]












  ;;;;;;;;;;;;;;;;;;; A FEW INDICATORS NEED GLOBAL EVALUATION

  ;; Reports the cumulative number of decisions, by oversight and by resolution, the ratio of the latter to the former, as well as the number of flights, either by postponemt or buckpassing, inside and outside organizations.
  if (print? and stop-at > 0 and ticks = stop-at - 1) [
    file-open "oversights.txt"
    file-write cum-oversights
    file-close
    file-open "resolutions.txt"
    file-write cum-resolutions
    file-close
    file-open "decision-efficiency.txt"
    if (cum-oversights > 0)
      [file-write cum-resolutions / cum-oversights]
    file-close
    file-open "decisions.txt"
    file-write cum-resolutions + cum-oversights
    file-close
    file-open "postponements-outside-organization.txt"
    file-write cum-postponements-outside-organization
    file-close
    file-open "postponements-inside-organization.txt"
    file-write cum-postponements-inside-organization
    file-close
    file-open "buck-passings-outside-organization.txt"
    file-write cum-buck-passings-outside-organization
    file-close
    file-open "buck-passings-inside-organization.txt"
    file-write cum-buck-passings-inside-organization
    file-close
  ]

  ;; Counts the number of independent participants with random heading, independent participants with heading 0, members of O-organizations, members of R-organizations,
  ;; the number of O-organizations and R-organizations at each step. Enters these numbers in appropriate lists.
  set random-independents-list lput (count participants with [color = yellow and heading != 0]) random-independents-list
  set headed-independents-list lput (count participants with [color = yellow and heading = 0]) headed-independents-list
  set O-organizations-members-list lput (count participants with [color = gray and label = "O"]) O-organizations-members-list
  set R-organizations-members-list lput (count participants with [color = gray and label = "R"]) R-organizations-members-list
  set O-organizations-list lput (count participants with [color = gray and owns-solution != nobody and label = "O"]) O-organizations-list
  set R-organizations-list lput (count participants with [color = gray and owns-solution != nobody and label = "R"]) R-organizations-list
  ;; At simulation end, writes these lists.
  if (print? and stop-at > 0 and ticks = stop-at - 1) [
    file-open "time-series-random-independents.txt"
    foreach random-independents-list
      [i -> file-write i]
    file-close
    file-open "time-series-headed-independents.txt"
    foreach headed-independents-list
      [i -> file-write i]
    file-close
    file-open "time-series-O-organizations-members.txt"
    foreach O-organizations-members-list
      [i -> file-write i]
    file-close
    file-open "time-series-R-organizations-members.txt"
    foreach R-organizations-members-list
      [i -> file-write i]
    file-close
    let average-number-organizations 0
    file-open "time-series-O-organizations.txt"
    foreach O-organizations-list [i ->
      file-write i
      set average-number-organizations average-number-organizations + i
    ]
    file-close
    file-open "time-series-R-organizations.txt"
    foreach R-organizations-list [i ->
      file-write i
      set average-number-organizations average-number-organizations + i
    ]
    file-close
    if (stop-at > 0)
      [set average-number-organizations average-number-organizations / stop-at]
    file-open "average-number-organizations.txt"
    file-write average-number-organizations
    file-close
  ]

  ;; The percentage of decisions made by organization founders, organization associates, and independent participants.
  if (count participants with [color = gray and owns-solution != nobody] != 0)
    [set percent-founders-deciding 100 * (num-founders-oversights + num-founders-resolutions) / count participants with [color = gray and owns-solution != nobody]]
  set cum-percent-founders-deciding cum-percent-founders-deciding + percent-founders-deciding
  set ave-percent-founders-deciding cum-percent-founders-deciding / (ticks + 1)
  set num-founders-oversights 0
  set num-founders-resolutions 0
  set percent-founders-deciding 0
  if (count participants with [color = gray and owns-solution = nobody] != 0)
    [set percent-associates-deciding 100 * (num-associates-oversights + num-associates-resolutions) / count participants with [color = gray and owns-solution = nobody]]
  set cum-percent-associates-deciding cum-percent-associates-deciding + percent-associates-deciding
  set ave-percent-associates-deciding cum-percent-associates-deciding / (ticks + 1)
  set num-associates-oversights 0
  set num-associates-resolutions 0
  set percent-associates-deciding 0
  if (count participants with [color = yellow] != 0)
    [set percent-independents-deciding 100 * (num-independents-oversights + num-independents-resolutions) / count participants with [color = yellow]]
  set cum-percent-independents-deciding cum-percent-independents-deciding + percent-independents-deciding
  set ave-percent-independents-deciding cum-percent-independents-deciding / (ticks + 1)
  set num-independents-oversights 0
  set num-independents-resolutions 0
  set percent-independents-deciding 0
  ;; At simulation end, writes the percentages of organization founders, organization associates and independent participants making decisions.
  if (print? and stop-at > 0 and ticks = stop-at - 1) [
    file-open "founders-making-decisions.txt"
    file-write ave-percent-founders-deciding
    file-close
    file-open "associates-making-decisions.txt"
    file-write ave-percent-associates-deciding
    file-close
    file-open "independents-making-decisions.txt"
    file-write ave-percent-independents-deciding
    file-close
  ]

  ;; Computes the ratios of decisions by oversight to decisions by resolution.
  if (cum-resolutions-founders > 0)
    [set ove/res-founders cum-oversights-founders / cum-resolutions-founders]
  if (cum-resolutions-associates > 0)
    [set ove/res-associates cum-oversights-associates / cum-resolutions-associates]
  if (cum-resolutions-independents > 0)
    [set ove/res-independents cum-oversights-independents / cum-resolutions-independents]
  ;; At simulation end, writes these data on a file.
  if (print? and stop-at > 0 and ticks = stop-at - 1) [
    file-open "ove-res-founders.txt"
    file-write ove/res-founders
    file-close
    file-open "ove-res-associates.txt"
    file-write ove/res-associates
    file-close
    file-open "ove-res-independents.txt"
    file-write ove/res-independents
    file-close
  ]

  ;; Measures the size of organizations and counts organizations by size. Organization size is in the range [1, (worldXSize * worldYSize)].
  set O-organization-size-list []
  set R-organization-size-list []
  ask participants with [color = gray and owns-solution != nobody and label = "O"] [
    set organization-size count participants with [organization = [organization] of myself]
    set O-organization-size-list fput organization-size O-organization-size-list
  ]
  ask participants with [color = gray and owns-solution != nobody and label = "R"] [
    set organization-size count participants with [organization = [organization] of myself]
    set R-organization-size-list fput organization-size R-organization-size-list
  ]
  ;; Cumulative organization size is necessary in order to compute distributions of organizations by size.
  foreach O-organization-size-list
    [x -> set cum-O-organization-size-list fput x cum-O-organization-size-list]
  foreach R-organization-size-list
    [y -> set cum-R-organization-size-list fput y cum-R-organization-size-list]
  ;; At simulation end, size distributions are computed.
  if (print? and stop-at > 0 and ticks = stop-at - 1) [
    ;; Distribution arrays are initialized. Arrays are in order, because 'set' does not apply to list items.
    let O-organization-size-distribution array:from-list n-values (world-width * world-height) [0]
    let R-organization-size-distribution array:from-list n-values (world-width * world-height) [0]
    ;; Distributions of organizations by size are computed. 'x' and 'y' represent organization size, '(x - 1)' and '(y - 1)' represent position in the size distribution: with '+ 1', its value is increased by one.
    foreach cum-O-organization-size-list
      [x -> array:set O-organization-size-distribution (x - 1) (array:item O-organization-size-distribution (x - 1) + 1)]
    foreach cum-R-organization-size-list
      [y -> array:set R-organization-size-distribution (y - 1) (array:item R-organization-size-distribution (y - 1) + 1)]

    ;; These lists entail distributions of organizations by size: the distribution arrays are pasted into them. For each list, the mean is written in a separate file.
    ;; Step 1: O-organizations
    let O-organization-size-distribution-list array:to-list O-organization-size-distribution
    let O-organization-size-distribution-mean 0
    let index-O-size 1
    let total-O-organization-number 0
    file-open "O-size-distribution.txt"
    foreach O-organization-size-distribution-list [
      x -> file-write x
      set O-organization-size-distribution-mean O-organization-size-distribution-mean + index-O-size * x
      set total-O-organization-number total-O-organization-number + x
      set index-O-size index-O-size + 1
    ]
    file-close
    ifelse (total-O-organization-number > 0)
      [set O-organization-size-distribution-mean (O-organization-size-distribution-mean / total-O-organization-number)]
      [set O-organization-size-distribution-mean 0]
    file-open "O-size-distribution-mean.txt"
    file-write O-organization-size-distribution-mean
    file-close
    ;; Step 2: R-organizations
    let R-organization-size-distribution-list array:to-list R-organization-size-distribution
    let R-organization-size-distribution-mean 0
    let index-R-size 1
    let total-R-organization-number 0
    file-open "R-size-distribution.txt"
    foreach R-organization-size-distribution-list [
      y -> file-write y
      set R-organization-size-distribution-mean R-organization-size-distribution-mean + index-R-size * y
      set total-R-organization-number total-R-organization-number + y
      set index-R-size index-R-size + 1
    ]
    file-close
    ifelse (total-R-organization-number > 0)
      [set R-organization-size-distribution-mean (R-organization-size-distribution-mean / total-R-organization-number)]
      [set R-organization-size-distribution-mean 0]
    file-open "R-size-distribution-mean.txt"
    file-write R-organization-size-distribution-mean
    file-close
  ]

  ;; At simulation end, mortality distributions are eventually printed.
  if (print? and stop-at > 0 and ticks = stop-at - 1) [
    ;; Distribution arrays are initialized. Arrays are in order, because 'set' does not apply to list items.
    let O-organization-mortality-distribution array:from-list []
    if (not empty? O-mortality-list)
      [set O-organization-mortality-distribution array:from-list n-values stop-at [0]]
    let R-organization-mortality-distribution array:from-list []
    if (not empty? R-mortality-list)
      [set R-organization-mortality-distribution array:from-list n-values stop-at [0]]
    ;; Distributions of organizations by mortality are computed.
    ;; Indices 'v' and 'w' represent O-organizations and R-organizations age at death, respectively.
    ;; Later on, these become positions in the mortality distribution.
    ;; With '+ 1', its value is increased by one.
    if (not empty? O-mortality-list) [
      foreach O-mortality-list
        [v -> array:set O-organization-mortality-distribution v (array:item O-organization-mortality-distribution v + 1)]
    ]
    if (not empty? R-mortality-list) [
      foreach R-mortality-list
        [w -> array:set R-organization-mortality-distribution w (array:item R-organization-mortality-distribution w + 1)]
    ]
    ;; These lists entail distributions of organizations by mortality: the distribution arrays are pasted into them. For each list, the mean is written in a separate file.
    ;; Step 1: O-organizations
    let O-organization-mortality-distribution-list array:to-list O-organization-mortality-distribution
    let O-organization-mortality-distribution-mean 0
    let index-O-mortality 1
    let total-O-organization-deaths 0
    file-open "O-mortality-distribution.txt"
    if (not empty? O-organization-mortality-distribution-list) [
      foreach O-organization-mortality-distribution-list [
        v -> file-write v
        set O-organization-mortality-distribution-mean O-organization-mortality-distribution-mean + index-O-mortality * v
        set total-O-organization-deaths total-O-organization-deaths + v
        set index-O-mortality index-O-mortality + 1
      ]
    ]
    file-close
    ifelse (total-O-organization-deaths > 0)
      [set O-organization-mortality-distribution-mean (O-organization-mortality-distribution-mean / total-O-organization-deaths)]
      [set O-organization-mortality-distribution-mean 0]
    file-open "O-mortality-distribution-mean.txt"
    file-write O-organization-mortality-distribution-mean
    file-close
    ;; Step 2: R-organizations
    let R-organization-mortality-distribution-list array:to-list R-organization-mortality-distribution
    let R-organization-mortality-distribution-mean 0
    let index-R-mortality 1
    let total-R-organization-deaths 0
    file-open "R-mortality-distribution.txt"
    if (not empty? R-organization-mortality-distribution-list) [
      foreach R-organization-mortality-distribution-list [
        w -> file-write w
        set R-organization-mortality-distribution-mean R-organization-mortality-distribution-mean + index-R-mortality * w
        set total-R-organization-deaths total-R-organization-deaths + w
        set index-R-mortality index-R-mortality + 1
      ]
    ]
    file-close
    ifelse (total-R-organization-deaths > 0)
      [set R-organization-mortality-distribution-mean (R-organization-mortality-distribution-mean / total-R-organization-deaths)]
      [set R-organization-mortality-distribution-mean 0]
    file-open "R-mortality-distribution-mean.txt"
    file-write R-organization-mortality-distribution-mean
    file-close
  ]

  ;; Fills the list of blocked decisions life lengths.
  ask patches [
    if (pcolor != white and plabel != "" and (ticks - plabel) > 0) [
      set blocked-time-list fput (ticks - plabel) blocked-time-list
      set plabel ""
    ]
  ]
  ;; At simulation end, writes the list of blocked decisions life lengths as well as its mean.
  if (print? and stop-at > 0 and ticks = stop-at - 1) [
    let blocked-mean-life-lengths 0
    file-open "blocked-life-lengths.txt"
    foreach blocked-time-list [
      i -> file-write i
      set blocked-mean-life-lengths blocked-mean-life-lengths + i
    ]
    file-close
    ifelse (empty? blocked-time-list)
      [set blocked-mean-life-lengths 0]
      [set blocked-mean-life-lengths blocked-mean-life-lengths / (length blocked-time-list)]
    file-open "blocked-mean-life-lengths.txt"
    file-write blocked-mean-life-lengths
    file-close
  ]




  ;;;;;;;;;;;;;;;;;;;;;; TICK UPDATING AND SIMULATION STOP

  ;; The number of ticks is updated.
  tick

  ;; The simulation is stopped as soon as the maximum number of steps is reached.
  if (stop-at > 0 and ticks = stop-at)
    [stop]


end  ; the 'go' procedure ends here

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@#$#@#$#@
GRAPHICS-WINDOW
467
10
1895
1439
-1
-1
28.4
1
10
1
1
1
0
1
1
1
0
49
0
49
0
0
1
ticks
50.0

SLIDER
9
44
163
77
agents-per-breed
agents-per-breed
0
1000
200.0
10
1
NIL
HORIZONTAL

BUTTON
9
10
111
44
Set Up
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
215
10
317
45
Go Until
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
110
10
214
44
Go Step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
316
78
468
112
min-difficulty
min-difficulty
0
10
0.0
0.1
1
NIL
HORIZONTAL

SLIDER
163
78
316
111
min-efficiency
min-efficiency
0
1
0.0
0.05
1
NIL
HORIZONTAL

SLIDER
10
78
164
112
min-ability
min-ability
0
10
0.0
0.1
1
NIL
HORIZONTAL

PLOT
9
418
468
581
Decisions and Flights
step
NIL
0.0
100.0
0.0
1.0
true
true
"" ""
PENS
"Oversights" 1.0 0 -13791810 true "" "plot cum-oversights"
"Resolutions" 1.0 0 -13840069 true "" "plot cum-resolutions"
"Postponements" 1.0 0 -6459832 true "" "plot cum-postponements-outside-organization + cum-postponements-inside-organization"
"Buck-Passings" 1.0 0 -16777216 true "" "plot cum-buck-passings-outside-organization + cum-buck-passings-inside-organization"

SLIDER
10
111
163
144
max-ability
max-ability
0
10
10.0
0.1
1
NIL
HORIZONTAL

SLIDER
316
111
468
145
max-difficulty
max-difficulty
0
10
10.0
0.1
1
NIL
HORIZONTAL

SLIDER
163
111
316
144
max-efficiency
max-efficiency
0
1
1.0
0.05
1
NIL
HORIZONTAL

SLIDER
316
12
468
46
stop-at
stop-at
0
5000
5000.0
100
1
NIL
HORIZONTAL

MONITOR
162
275
315
320
Postponed Problems
count opportunities with [charged?]
17
1
11

MONITOR
315
275
468
320
Passed Problems
count participants with [charged?]
17
1
11

MONITOR
9
230
162
275
Decisions by Resolution
cum-resolutions
17
1
11

MONITOR
9
185
162
230
Decisions by Oversight
cum-oversights
17
1
11

MONITOR
162
230
335
275
Postponements Outside
cum-postponements-outside-organization
17
1
11

MONITOR
315
230
469
276
Buck-Passings Outside
cum-buck-passings-outside-organization
17
1
11

MONITOR
9
275
162
320
Blocked Decisions
count opportunities with [blocked?]
17
1
11

MONITOR
315
365
468
410
Ove / Res Independents
ove/res-independents
17
1
11

MONITOR
162
365
315
410
Ove / Res Associates
ove/res-associates
17
1
11

MONITOR
9
365
162
410
Ove / Res Founders
ove/res-founders
17
1
11

MONITOR
315
320
468
365
% Independents Deciding
ave-percent-independents-deciding
17
1
11

MONITOR
162
320
315
365
% Associates Deciding
ave-percent-associates-deciding
17
1
11

MONITOR
9
320
162
365
 % Founders Deciding
ave-percent-founders-deciding
17
1
11

SWITCH
10
144
164
178
postpone?
postpone?
0
1
-1000

SWITCH
163
144
317
178
buck-pass?
buck-pass?
0
1
-1000

SWITCH
163
45
316
78
organizations?
organizations?
0
1
-1000

PLOT
8
744
468
907
Number of Organizations
NIL
NIL
0.0
100.0
0.0
5.0
true
true
"" ""
PENS
"All Organizations" 1.0 0 -16777216 true "" "plot count participants with [color = gray and owns-solution != nobody]"
"O-organizations" 1.0 0 -13791810 true "" "plot count participants with [color = gray and owns-solution != nobody and label = \"O\"]"
"R-organizations" 1.0 0 -13840069 true "" "plot count participants with [color = gray and owns-solution != nobody and label = \"R\"]"

PLOT
8
907
468
1070
Organization Size
size
NIL
1.0
100.0
0.0
100.0
true
true
"" ""
PENS
"O-organizations" 1.0 1 -13791810 true "" "histogram cum-O-organization-size-list"
"R-organizations" 1.0 1 -13840069 true "" "histogram cum-R-organization-size-list"

MONITOR
162
185
326
230
Postponements Inside
cum-postponements-inside-organization
17
1
11

MONITOR
315
185
468
230
Buck-Passings Inside
cum-buck-passings-inside-organization
17
1
11

PLOT
8
1070
468
1233
Mortality of Organizations
age
NIL
0.0
1000.0
0.0
10.0
true
true
"" ""
PENS
"O-organizations" 10.0 1 -13791810 true "" "histogram O-mortality-list"
"R-organizations" 10.0 1 -13840069 true "" "histogram R-mortality-list"

PLOT
8
580
468
743
Participants
NIL
NIL
0.0
100.0
0.0
10.0
true
true
"" ""
PENS
"All Indep. Partic." 1.0 0 -1184463 true "" "plot count participants with [color = yellow]"
"Indep. Part. Ready" 1.0 0 -7171555 true "" "plot count participants with [color = yellow and heading = 0]"
"All Org. Members" 1.0 0 -7500403 true "" "plot count participants with [color = gray]"
"Organiz. Founders" 1.0 0 -16777216 true "" "plot count participants with [color = gray and owns-solution != nobody]"

SLIDER
316
45
468
79
decay
decay
0
0.1
0.07
0.01
1
NIL
HORIZONTAL

SWITCH
316
144
468
178
print?
print?
1
1
-1000

@#$#@#$#@
## WHAT IS IT?

The Garbage Can Model (GCM) of organizational choice (Cohen, March and Olsen 1972) is a prominent model of organizational decision-making. It is also a unique example of a decision theory developed and expressed by means of computer simulations. With a different code we cast it as an agent-based model (Fioretti and Lomi 2008a, 2008b) and linked it to more recent streams in organization science (Fioretti and Lomi 2010).

With this code we move from representing decision-making within one single organization to an ecology where organizations emerge, grow and dissolve while making decisions according to GCM rules. We are able to show that this ecology of Garbage Cans reproduces two different empirical shapes of firms' mortality distribution known as 'liability of newness' and 'liability of adolescence', respectively.



## THE GARBAGE CAN MODEL OF ONE SINGLE ORGANIZATION

The GCM was conceived in order to represent decision-making within one single organization. In this model, this is an option that can be selected by means of the switch "organizations?"

The GCM can be seen as a sort of chemical reactor where 'participants' (decision-makers), 'opportunities', 'solutions' and 'problems' move randomly. Through random meetings of these elements, decisions are made. According to Cohen, March and Olsen (1972), organizations whose processes of decision-making are akin to the GCM may be called 'organized anarchies'.

We interpreted the GCM as an agent-based model where participants, opportunities, solutions and problems are four classes of agents. Participants are recognizable as stylized humans. Opportunities are denoted by orange squares. Solutions are denoted by red circles. Problems are denoted by violet triangles.

Participants are characterized by their ability to solve  
problems. Solutions are characterized by their efficiency. Problems are characterized by their difficulty.

Ability, efficiency and difficulty take values within ranges specified by the sliders "min-ability" and "max-ability", "min-efficiency" and "max-efficiency", "min-difficulty" and "max-difficulty", respectively. Values are assigned to agents according to uniform distributions that span the selected range.

A decision "by resolution" takes place when at least one participant, at least one opportunity, at least one solution and at least one problem are on the same patch and the sum of the abilities of the participants on the patch, multiplied by the efficiency of the most efficient solution on the patch, is greater or equal to the sum of the difficulties of the problems on the patch. Most often, decision-making by resolution occurs when just one participant, one choice opportunity, one solution and one problem happen to be on the same patch and the ability of the participant, multiplied by the efficiency of the solution, is greater or equal to the difficulty of the problem. The patch where a decision by resolution is being made takes on a green color.

However, a key feature of the GCM is that a lot of decision-making may not solve any problem at all. For instance, choice opportunities may be used as showrooms in corporate politics rather than exploited to solve problems. In these cases, decision is made "by oversight" - in the sense that problems are ignored.

Decision-making by oversight takes place when at least one participant, at least one choice opportunity and at least one solution are on the same patch. No problem needs to be there, because no problem must be solved. No further condition is required. The patch where a decision by oversight is being made takes a sky-blue color.

If problems find themselves on the same patch with participants, solutions and choice opportunities, but the sum of the abilities of the participants multiplied by the efficiency of the most efficient solution is less than the sum of the difficulties of the problems, all agents on the patch are blocked and no decision is made. The patch where a decision process is blocked takes a on white color.

Participants can fly away from the most difficult problem involved in a blocked decision process. This is called a "flight" in the GCM. A flight may take place in two ways:

- By postponing the most difficult problem. This was the only kind of flight envisioned by Cohen, March and Olsen (1972). A flight by postponement occurs if an additional opportunity walks on the patch where a decision process is blocked, in which case the most difficult problem is bound to this opportunity, and the two start walking together. The patch where they are takes on a brown color. Postponing decision-making is enabled by the switch 'postpone?'

- By buck-passing. This kind of flight has been introduced in our update of the original model (Fioretti and Lomi 2010). A flight by buck-passing can only be attempted after a flight by postponement failed. Buck-passing occurs if at least two participants find themselves on a patch where a decision process is blocked: the most difficult problem is bound to the least able participant, and the two start walking together. The patch where they are takes on a brown color. The possibility of buck-passing is enabled by the switch 'buck-pass?'

Once the most difficult problem left, the remaining agents may be able to make a decision, either by resolution or by oversight. Thus, flights favor decision-making.

In this decision process choice opportunities take the role of "garbage cans" where solutions and problems are dumped. Hence the name of the model.





## THE GARBAGE CAN MODEL OF AN ORGANIZATIONAL ECOLOGY

This extension is based on a novel interpretation of the space where agents move. In our novel interpretation, this space represents society at large understood as a sort of primordial soup where organizations eventually emerge.

If no organization is there, the first one is created when an independent participant makes a decision. This participant retains the solution that it employed. This compound of a decision-maker and a solution represents the core of a new organization whose solution represents its distinctive culture and routines.

If at least one organization is there, diffusion of entrepreneurial ideas is necessary in order to create organizations. Independent participants scan their eight nearest neighbours while moving randomly in the primordial soup. If an organization member is visible, this independent participant will be able to found an organization the next time it makes a decision.

Independent participants who never came across an organization are depicted as randomly walking yellow men with random heading. Independent participants who already came across an organization are depicted as randomly walking yellow men with fixed vertical heading. Finally, organization members are depicted as gray men who stay put with vertical heading. Organization founders can be recognized by the fact that a solution stays with them. A label "R" or "O" reminds whether an organization has been founded with a decision by resolution or oversight, respectively.

Independent participants and organization members make decisions by resolution and oversight with the same rules as in the basic GCM. However, in order to avoid that one opportunity is endlessly used for a neverending series of decisions by oversight, opportunities entering an organization can only be used once.

Decisions can get blocked for the same reason as in the basic GCM, both outside and inside organizations. Flights occur with the same rules, except that organization members can postpone difficult problems to any opportunity inside the organization and they can pass difficult problem to any colleague.

Consequently, organization members are more likely to make decisions than independent participants. First, because the organization's solution is always available to them. Secondly, because flights are easier for them.

Independent participant who happen to walk on one of the patches where an organization is, they join it. Organizations take a roughly circular shape where we distinguish two hierarchical levels: the founder at the centre with the solution that she owns, whereas organization associates are around him.

Organizations exist insofar their resource endowments is greater than zero. At foundation, organizations are endowed with an amount of resources that is equal to the ability of their founders. Subsequently, any time organizations make a decision by resolution they increase their endowment by an amount equal to the difficulty of the problems that they solved. However, at each time step their endowment decreases by an amount proportional to their size and regulated by a model parameter. When their endowment of resources shrinks down to zero, organizations are disbanded. Their members become independent participants whose memory is erased. Their solution is set free to move, as well as opportunities and problems that are eventually blocked within the organization. Postponed and buck-passed problems that happen to walk on an organization's area when it is disbanded, as well as the opportunities and participants to which they are paired, are freed from one another.




## HOW TO USE IT

The following switches and sliders are available:

- SetUp: Get ready for simulation.

- Go Step: Go ahead by one step only.

- Go Until: Go ahead by a number of steps specified by 'stop-at' (see below).

- stop-at: Stops the simulation after a selected number of steps. It can be overcome by pressing 'Go Until' again.

- agents-per-breed: The number of participants, equal to the number of opportunities, the number of solutions and the number of problems.

- postpone?: Allows flights by postponement.

- buck-pass?: Allows flights by buck-passing.

- organizations?: Allows the emergence of organizations.

- decay: The percent decay at each step, later on multiplied by organization size.

- min-ability: The minimum ability of participants.

- max-ability: The maximum ability of participants.

- min-efficiency: The minimum efficiency of solutions.

- max-efficiency: The maximum efficiency of solutions.

- min-difficulty: The minimum difficulty of problems.

- max-difficulty: The maximum difficulty of problems.

- print?: Print outcomes on files.





## THINGS TO NOTICE

The following monitors are available:

- The cumulative number of decisions by oversight;

- The cumulative number of decisions by resolution;

- The cumulative number of flights by postponement inside organizations;

- The cumulative number of flights by postponement outside organizations;

- The cumulative number of flights by buck-passing inside organizations;

- The cumulative number of flights by buck-passing outside organizations;

- The current number of blocked decision processes;

- The current number of postponed problems;

- The current number of passed problems;

- The percentage of organization founders making decisions;

- The percentage of organization associates making decisions;

- The percentage of independent participants making decisions;

- The ratio of decisions by oversight to decisions by resolution for organization founders;

- The ratio of decisions by oversight to decisions by resolution for organization associates;

- The ratio of decisions by oversight to decisions by resolution for independent participants;

The following graphs are drawn:

- The time series of the number of decisions by oversight, decisions by resolution, flights by postponement and flights by buck-passing;

- The time series of participants split into independent participants, independent participants ready to found an organization, organization founders and organization associates;

- The time series of the number of organizations founded by means of a decision by oversight and by means of a decision by resolution;

- The size distributions of organizations founded with decisions by resolution and oversight, respectively;

- The mortality distibution of organizations founded with decisions by resolution and oversight, respectively.




## THINGS TO TRY

Check the following properties with different parameter values: 

- Most decisions are made by oversight, only a few decisions are made by resolution. This can be readily seen by comparing the monitors 'Decisions by Oversight' and 'Decisions by Resolution'.

- At the highest hierarchical levels, decisions by resolution are particularly rare. This can be seen by comparing the monitors 'Founders Ove / Res', 'Associates Ove / Res' and 'Independents Ove / Res'.

- In general, organization founders make more decisions than organization associates, and both of them make more decisions than independent participants. This can be observed from the monitors '% Founders Deciding', '% Associates Deciding' and '% Independents Deciding'.

- Flights ease decision-making and make it easier for organizations to exist and to grow. This can be seen from the number of blocked decision processes, the number of decisions as well as the number of organizations that are formed as well as the time they last.

- The size distribution of organizations founded with decisions by oversight is more left-skewed than the size distribution of organizations founded with decisions by resolution.

- The mortality distribution of organizations founded with decisions by resolution peaks after the mortality distribution of organizations founded with decisions by oversight.

Tentatively, organizations founded with decisions by oversight are subject to a liability of newness, whereas organizations founded with decisions by resolution are subject to a liability of adolescence. This statement is in accord with empirical evidence.





## CREDITS AND REFERENCES

Cohen M.D., March J.G. and Olsen J.P. (1972) A Garbage Can Model of Organizational Choice. Administrative Science Quarterly, 17 (1): 1-25.

Fioretti G. and Lomi A. (2008a) An Agent-Based Representation of the Garbage Can Model of Organizational Choice. Journal of Artificial Societies and Social Simulation, 11 (1). 

Fioretti G. and Lomi A. (2008b) The Garbage Can Model of Organizational Choice: An agent-based reconstruction. Simulation Modelling Practice and Theory, 16 (2): 192-217.

Fioretti G. and Lomi A. (2010) Passing the Buck in the Garbage Can Model of Organizational Choice. Computational and Mathematical Organization Theory, 16 (2): 113-143.

Fioretti G. and Lomi A. (2012) Garbage Can Ecologies: An Agent-Based Exploration. In A. Lomi and R. Harrison (Eds.), The Garbage Can Model of Organizational Choice: Looking Forward at Forty. Bingley (UK): Emerald Group Publishing, Research in the Sociology of Organizations, Volume 36.

This model was built by:  
Guido Fioretti  
University of Bologna  
Department of Management



## HOW TO CITE

Fioretti G. and Lomi A. (2020) Emergence of Organizations out of Garbage Can Dynamics. Working Paper.



## COPYRIGHT NOTICE

This software was developed on NetLogo 6.1.1. This software is distributed under the GNU Public Licence (GPL) v.3.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

ant
true
0
Polygon -7500403 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7500403 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7500403 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186
Polygon -7500403 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7500403 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7500403 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7500403 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7500403 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7500403 true true 249 107 211 147 168 147 168 150 213 150

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -1184463 true false 151 152 137 77 105 67 89 67 66 74 48 85 36 100 24 116 14 134 0 151 15 167 22 182 40 206 58 220 82 226 105 226 134 222
Polygon -16777216 true false 151 150 149 128 149 114 155 98 178 80 197 80 217 81 233 95 242 117 246 141 247 151 245 177 234 195 218 207 206 211 184 211 161 204 151 189 148 171
Polygon -7500403 true true 246 151 241 119 240 96 250 81 261 78 275 87 282 103 277 115 287 121 299 150 286 180 277 189 283 197 281 210 270 222 256 222 243 212 242 192
Polygon -16777216 true false 115 70 129 74 128 223 114 224
Polygon -16777216 true false 89 67 74 71 74 224 89 225 89 67
Polygon -16777216 true false 43 91 31 106 31 195 45 211
Line -1 false 200 144 213 70
Line -1 false 213 70 213 45
Line -1 false 214 45 203 26
Line -1 false 204 26 185 22
Line -1 false 185 22 170 25
Line -1 false 169 26 159 37
Line -1 false 159 37 156 55
Line -1 false 157 55 199 143
Line -1 false 200 141 162 227
Line -1 false 162 227 163 241
Line -1 false 163 241 171 249
Line -1 false 171 249 190 254
Line -1 false 192 253 203 248
Line -1 false 205 249 218 235
Line -1 false 218 235 200 144

bird1
false
0
Polygon -7500403 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7500403 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6459832 true false 150 32 157 162
Polygon -13345367 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7500403 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7500403 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6459832 true false 150 32 157 162
Polygon -13345367 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7500403 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7500403 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6459832 true false 150 32 157 162
Polygon -13345367 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7500403 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7500403 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Rectangle -7500403 true true 46 47 255 255

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7500403 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7500403 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7500403 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7500403 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7500403 true 167 47 159 82
Line -7500403 true 136 47 145 81
Circle -7500403 true true 165 45 8
Circle -7500403 true true 134 45 6
Circle -7500403 true true 133 44 7
Circle -7500403 true true 133 43 8

circle
false
0
Circle -7500403 true true 34 34 230

opportunity
true
0
Rectangle -955883 true false 45 45 255 255

participant
true
4
Circle -1184463 true true 125 5 63
Rectangle -1184463 true true 120 90 195 225
Polygon -1184463 true true 120 90 30 150 45 180 113 139 120 140
Polygon -1184463 true true 195 90 285 150 270 180 185 137
Polygon -1184463 true true 120 225 100 309 138 309 150 195
Polygon -1184463 true true 165 195 180 308 212 308 180 180
Rectangle -1184463 true true 150 30 165 120

person
false
0
Circle -7500403 true true 155 20 63
Rectangle -7500403 true true 158 79 217 164
Polygon -7500403 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7500403 true true 216 83 267 123 248 143 215 107
Polygon -7500403 true true 167 163 145 234 183 234 183 163
Polygon -7500403 true true 195 163 195 233 227 233 206 159

problem
true
0
Polygon -8630108 true false 149 1 31 239 271 239

solution
true
0
Circle -2674135 true false 75 73 151
Circle -2674135 true false 11 12 273

spacecraft
true
0
Polygon -7500403 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7500403 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7500403 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8630108 true false 195 75 195 120 240 120 240 75
Polygon -8630108 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7500403 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8630108 true false 90 210 105 225 120 210
Polygon -8630108 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7500403 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8630108 true false 210 210 195 225 180 210
Polygon -8630108 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7500403 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf-left
false
3
Polygon -6459832 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6459832 true true 87 80 79 55 76 79
Polygon -6459832 true true 81 75 70 58 73 82
Polygon -6459832 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6459832 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6459832 true true 116 140 114 189 105 137
Rectangle -6459832 true true 109 150 114 192
Rectangle -6459832 true true 111 143 116 191
Polygon -6459832 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6459832 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6459832 true true 214 134 203 168 192 148
Polygon -6459832 true true 204 151 203 176 193 148
Polygon -6459832 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6459832 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6459832 true true 201 99 214 69 215 99
Polygon -6459832 true true 207 98 223 71 220 101
Polygon -6459832 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6459832 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6459832 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6459832 true true 48 143 58 141
Polygon -6459832 true true 46 136 68 137
Polygon -6459832 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6459832 true true 38 138 66 149
Polygon -6459832 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6459832 true true 67 122 96 126 63 144
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Output" repetitions="10000" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="agents-per-breed">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decay">
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="print?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
